summaryrefslogtreecommitdiffstats
path: root/kmymoney2/dialogs/kexportdlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/dialogs/kexportdlg.h')
-rw-r--r--kmymoney2/dialogs/kexportdlg.h41
1 files changed, 21 insertions, 20 deletions
diff --git a/kmymoney2/dialogs/kexportdlg.h b/kmymoney2/dialogs/kexportdlg.h
index cad5091..9afca12 100644
--- a/kmymoney2/dialogs/kexportdlg.h
+++ b/kmymoney2/dialogs/kexportdlg.h
@@ -23,8 +23,8 @@
// ----------------------------------------------------------------------------
// QT Headers
-#include <qstring.h>
-#include <qcheckbox.h>
+#include <tqstring.h>
+#include <tqcheckbox.h>
// ----------------------------------------------------------------------------
// KDE Headers
@@ -39,9 +39,9 @@
/**
* This class is used to select the required user input to export
- * a specified account to the popular QIF format.
- * It relies upon the QIF file handling routines in MyMoneyQifProfile and
- * MyMoneyQifWriter to do the actual writing of QIF files.
+ * a specified account to the popular TQIF format.
+ * It relies upon the TQIF file handling routines in MyMoneyQifProfile and
+ * MyMoneyQifWriter to do the actual writing of TQIF files.
*
* It uses the global KConfig object to read and write the application
* settings.
@@ -50,47 +50,48 @@
*
* @author Felix Rodriguez, Michael Edwardes, Thomas Baumgart 2000-2003
*
- * @short A class to select user data required to export a specified account to the popular QIF format.
+ * @short A class to select user data required to export a specified account to the popular TQIF format.
**/
class KExportDlg : public KExportDlgDecl
{
Q_OBJECT
+ TQ_OBJECT
public:
- KExportDlg(QWidget *parent);
+ KExportDlg(TQWidget *tqparent);
~KExportDlg();
/**
* This method returns the filename entered into the edit field
*
* @return QString with filename
*/
- const QString filename(void) const { return m_qlineeditFile->text(); };
+ const TQString filename(void) const { return m_qlineeditFile->text(); };
/**
* This method returns the account id that has been selected for export
*
* @return QString with account id
*/
- QString accountId(void) const;
+ TQString accountId(void) const;
/**
* This method returns the name of the profile that has been selected
* for the export operation
*
* @return QString with profile name
*/
- const QString profile(void) const { return m_profileComboBox->currentText(); };
+ const TQString profile(void) const { return m_profileComboBox->currentText(); };
/**
* This method returns the start date of the export dialog
*/
- const QDate startDate(void) const { return m_kmymoneydateStart->date(); };
+ const TQDate startDate(void) const { return m_kmymoneydateStart->date(); };
/**
* This method returns the end date of the export dialog
*/
- const QDate endDate(void) const { return m_kmymoneydateEnd->date(); };
+ const TQDate endDate(void) const { return m_kmymoneydateEnd->date(); };
/**
* This method returns the state of the account checkbox
@@ -109,7 +110,7 @@ protected slots:
void slotOkClicked();
/**
- * Called when the user needs to browse the filesystem for a QIF file
+ * Called when the user needs to browse the filesystem for a TQIF file
*/
void slotBrowse();
@@ -130,7 +131,7 @@ protected slots:
*
* @param account The id of the selected account.
*/
- void checkData(const QString& account = QString());
+ void checkData(const TQString& account = TQString());
private:
void readConfig(void);
@@ -162,7 +163,7 @@ private:
* @param id Account id to add
* @param leadIn constant leadin to be added in front of the account name
*/
- // void addCategories(QStringList& strList, const QString& id, const QString& leadIn) const;
+ // void addCategories(TQStringList& strList, const TQString& id, const TQString& leadIn) const;
/**
* This method is used to return the account id of a given account name
@@ -171,10 +172,10 @@ private:
* @return the ID of the account will be returned.
* See MyMoneyFile::nameToAccount() for details.
*/
- // QString accountId(const QString& account) const;
+ // TQString accountId(const TQString& account) const;
private:
- QString m_lastAccount;
+ TQString m_lastAccount;
};
#endif
@@ -50,47 +50,48 @@
* This method returns the filename entered into the edit field
*
- * @return QString with filename
+ * @return TQString with filename
*/
@@ -50,47 +50,48 @@
* This method returns the account id that has been selected for export
*
- * @return QString with account id
+ * @return TQString with account id
*/
@@ -50,47 +50,48 @@
* for the export operation
*
- * @return QString with profile name
+ * @return TQString with profile name
*/